@@ -1,5 +1,5 @@
 
-# $Id: digest.R 24 2009-09-24 12:36:55Z edd $
+# $Id: digest.R 27 2009-12-03 15:41:30Z henrikb $
 
  digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256"),
                     serialize=TRUE, file=FALSE, length=Inf,
@@ -48,8 +48,11 @@
    if (file) {
      algoint <- algoint+100
      object <- path.expand(object)
-     if (file.access(object)<0) {
-       stop(c("Can't open input file:", object))
+     if (!file.exists(object)) {
+       stop("The file does not exist: ", object)
+     }
+     if (!isTRUE(!file.info(object)$isdir)) {
+       stop("The specified pathname is not a file: ", object)
      }
    }
    ## if skip is auto (or any other text for that matter), we just turn it
